# ===========================================================================
# JS da página de gerenciamento das mídias
# Author: Luís Dalmolin <luis@escape.ppg.br>
# ===========================================================================

App             = App || {}
App.Models      = App.Models || {}
App.Collections = App.Collections || {}
App.Views       = App.Views || {}

# ===================================================================================================
# MediaModelSize backbone itens 
# ===================================================================================================
App.Models.MediaModelSize = Backbone.Model.extend
    urlRoot: '/manager/midias-model/sizes'

    validate: (attrs, options) ->
        if isNaN( parseInt( attrs.width ) ) || isNaN( parseInt( attrs.height ) )
            return 'Altura e largura devem ser números inteiros'

        if prefix == ''
            return 'Preencha o prefixo'

        return

App.Collections.MediaModelSizes = Backbone.Collection.extend
    model: App.Models.MediaModelSize
    url: '/manager/midias-model/sizes'


# view de todos os tamanhos
App.Views.MediaModelSizes = Backbone.View.extend
    tagName: 'div'
    template: _.template( $('#template-sizes').html() )

    events:
        'click #btn-save-size': 'save'

    initialize: ->
        this.collection.on 'add', this.addOne, this
        this.render()

    render: ->
        this.$el.html this.template()
        this.collection.each this.addOne, this
        
        this

    addOne: (size) ->
        sizeView = new App.Views.MediaModelSize model: size
        this.$('#sizes').append sizeView.render().el

    save: ->
        resize = if $('#resize').prop('checked') then 1 else 0

        this.collection.create({
            'media_model_id' : Media.id
            'prefix'         : $('#prefix').val()
            'width'          : $('#width').val()
            'height'         : $('#height').val()
            'resize'         : resize
        }, { wait: true })

        this.clearForm()

    clearForm: ->
        $('#prefix').val('')
        $('#width').val('')
        $('#height').val('')
        $('#resize').prop('checked', false)

# view de um tamanho único
App.Views.MediaModelSize = Backbone.View.extend
    tagName: 'tr'
    template: _.template($('#template-size-item').html())

    events:
        'click .btn-delete-size': 'delete'

    initialize: ->
        this.model.on 'destroy', this.unrender, this

    render: ->
        this.$el.html this.template this.model.toJSON()

        return this

    delete: (e) ->
        e.preventDefault()

        this.model.destroy()

    unrender: -> 
        this.remove()


# ===================================================================================================
# Media page functions 
# ===================================================================================================
Media = {}
Media.$modalSizes = $('#modal-sizes')
Media.id   = null
Media.init = ->
    # abrindo o modal dos tamanhos 
    $('.btn-open-sizes').on 'click', (e) ->
        e.preventDefault()

        $this    = $(this)
        Media.id = $this.data('id')

        Media.fetchSizes()
        Media.openModal()
    

# buscando os tamanhos 
Media.fetchSizes = ->
    sizesCollections = new App.Collections.MediaModelSizes()

    sizesCollections.fetch({ data: { 'id': Media.id } }).success ->
        sizesView = new App.Views.MediaModelSizes({
            collection: sizesCollections
        })

        Media.$modalSizes.find('.modal-body').html sizesView.el

# abrindo o modal 
Media.openModal = ->
    Media.$modalSizes.modal('show')

# fechando o modal
Media.closeModal = ->
    Media.$modalSizes.modal('close')

Media.init()