<?php namespace EscapeWork\Manager\Medias\Controllers;

use EscapeWork\Manager\Controllers\ManagerController;
use EscapeWork\Manager\Medias\Upload;
use EscapeWork\Manager\Medias\Repositories\Media\MediaRepository;
use EscapeWork\Manager\Medias\Repositories\MediaModel\MediaModelRepository;
use App;
use View;
use Input;
use Msg;
use Redirect;
use Response;

class MediaController extends ManagerController
{

    public function __construct(MediaRepository $media, MediaModelRepository $mediaModel)
    {
        parent::__construct();

        $this->media      = $media;
        $this->mediaModel = $mediaModel;
    }

    /**
     * Configurando o model do produto, adicionando na view e setando a mensagem padrão
     */
    protected function configure($model)
    {
        $this->model           = $model;
        $this->media->model_id = $this->model->id;
        $this->media->setMediaModel(get_class($this->model));

        $this->mediaModel = $this->mediaModel->findOrFailBy('model', $this->media->media_model);
    }

    public function index($id, $model)
    {
        $this->configure($model);

        $view              = View::make('manager-medias::index');
        $view->medias      = $this->media->getMedias();
        $view->mediaModel  = $this->mediaModel;
        $view->model_title = $this->mediaModel->model_title;
        $view->model       = $model;

        return $view;
    }

    public function store($model_id, $model)
    {
        $this->configure($model);

        foreach (Input::file('files') as $file) {
            $this->media->insert($file);
        }

        return Redirect::route('manager.midias.index', array($model_id, get_class($model)));
    }

    public function update($model_id, $model, $id)
    {
        $this->configure($model);

        if (! $this->media = $this->media->find($id)) {
            return Response::json(array('error' => 'Foto não encontrada'));
        }

        $this->media->legend  = Input::get('legend');
        $this->media->credits = Input::get('credits');
        $this->media->save();

        return Response::json(array(
            'message' => 'A foto foi atualizada com sucesso!',
            'id'      => $this->media->id
        ));
    }

    public function updateOrder($model_id, $model, $id)
    {
        $this->configure($model);

        if (! $this->media = $this->media->find($id)) {
            return Response::json(array('error' => 'Foto não encontrada'));
        }

        $this->media->order = Input::get('order');
        $this->media->save();

        return Response::json(array(
            'message' => 'A foto foi atualizada com sucesso!',
            'id'      => $this->media->id
        ));
    }

    public function destroy($model_id, $model, $id)
    {
        $this->configure($model);
        $params = array($model_id, get_class($model));
        $this->media = $this->media->findOrFail($id);

        if ($this->media->delete()) {
            return Redirect::route('manager.midias.index', $params)
                        ->with('message', 'A mídia foi excluída com sucesso!');
        }

        return Redirect::route('manager.midias.index', $params)
                    ->with('error', 'Houve um erro ao excluir a mídia.');
    }

    public function destroyAll($model_id, $model)
    {
        $params = array($model_id, get_class($model));

        $this->configure($model);
        $this->media->deleteAll();

        return Redirect::route('manager.midias.index', $params)
                    ->with('message', 'As fotos foram excluídas com sucesso!');
    }
}
