<?php namespace EscapeWork\Manager\Medias\Models;

use EscapeWork\Manager\Medias\Models\MediaModelSize;
use EscapeWork\Manager\Medias\Upload;
use EscapeWork\LaravelHelpers\Eloquent;

class Media extends Eloquent
{

    /**
     * Table
     */
    protected $table = 'medias';

    /**
     * Regras para validação
     */
    public static $validationRules = array(
        'media_model' => array('required'),
        'model_id'    => array('required'),
        'file'        => array('required'),
        'mime'        => array('required'),
        'size'        => array('required'),
        'order'       => array('integer'),
    );

    /**
     * Mensagens para validação
     */
    public static $validationMessages = array(
        'model.required' => 'O nome da tabela é obrigatório'
    );

    /**
     * Fields
     */
    public $fillable = array(
        'id',
        'media_model',
        'model_id',
        'file',
        'mime',
        'size',
        'legend',
        'credits',
        'order',
        'active'
    );

    /**
     * Pasta de localização
     */
    public static $url = '/files/medias/';
    public static $dir = '/files/medias/';

    public function dir()
    {
        return public_path() . static::$dir;
    }

    /**
     * Scope for active medias only
     */
    public function scopeActive($query)
    {
        return $query->where('active', '=', true);
    }

    /**
     * Scope for default get Medias from
     */
    public function scopeGetActualModel($query)
    {
        return $query->where('media_model', '=', $this->media_model)
                     ->where('model_id', '=', $this->model_id);
    }

    /**
     * Polymorphical relation
     */
    public function medias()
    {
        return $this->morphTo();
    }
}
