<?php namespace EscapeWork\Manager\Medias\Models;

use EscapeWork\LaravelHelpers\Eloquent;

class MediaModelSize extends Eloquent
{

    /**
     * Table
     */
    protected $table = 'media_model_sizes';

    /**
     * Regras para validação
     */
    public static $validationRules = array(
        'prefix' => array('max:10'),
        'width'  => array('required', 'integer'),
        'height' => array('required', 'integer'),
        'resize' => array('required'),
    );

    /**
     * Mensagens para validação
     */
    public static $validationMessages = array(
        'prefix.required' => 'Preencha o prefixo do tamanho',
        'width.required'  => 'Preencha a largura do tamanho',
        'width.integer'   => 'Preencha a largura do tamanho com um valor inteiro',
        'height.required' => 'Preencha a altura do tamanho',
        'height.integer'  => 'Preencha a altura do tamanho com um valor inteiro',
        'resize.required' => 'Preencha se a imagem deve ou não ser redimensionada',
    );

    /**
     * Fillable fields
     */
    protected $fillable = array(
        'id',
        'media_model_id',
        'prefix',
        'width',
        'height',
        'resize',
        'created_at',
        'updated_at',
    );

    /**
     * Setando o campo resize
     */
    public function setResizeAttribute($value)
    {
        $this->attributes['resize'] = $value == 1 ? 1 : 0;
    }

    /**
     * Retornando um array com os tamanhos de um model
     */
    public function getSizes($model)
    {
        return $this->join('media_models', 'media_models.id', '=', 'media_model_sizes.media_model_id')
                    ->where('media_models.model', '=', $model)
                    ->get()
                    ->toArray();
    }
}
