<?php namespace EscapeWork\Manager\Medias\Providers;

use EscapeWork\Manager\Medias\Commands\ConfigureCommand;
use Illuminate\Support\ServiceProvider;
use Route;
use App;

class MediaServiceProvider extends ServiceProvider
{

    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        $this->package('escapework/manager-medias', 'manager-medias', realpath(__DIR__ . '/../../../../'));

        require_once(__DIR__ . '/../../../../routes.php');
    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->bindRepositories();
        $this->bindRoutes();
        $this->registerCommands();

        $this->app['config']->set('manager::packages.manager-medias', 'manager-medias');
    }

    protected function bindRepositories()
    {
        $this->app->bind('EscapeWork\Manager\Medias\Repositories\Media\MediaRepository', 'EscapeWork\Manager\Medias\Repositories\Media\EloquentMediaRepository');
        $this->app->bind('EscapeWork\Manager\Medias\Repositories\MediaModel\MediaModelRepository', 'EscapeWork\Manager\Medias\Repositories\MediaModel\EloquentMediaModelRepository');
        $this->app->bind('EscapeWork\Manager\Medias\Repositories\MediaModelSize\MediaModelSizeRepository', 'EscapeWork\Manager\Medias\Repositories\MediaModelSize\EloquentMediaModelSizeRepository');
    }

    protected function bindRoutes()
    {
        $this->app['router']->bind('model', function($modelString, $route)
        {
            $modelString = urldecode($modelString);

            $router = Route::getFacadeRoot();
            $params = explode('/', $router->getCurrentRequest()->getRequestUri());

            if (! class_exists($modelString) or ! isset($params[3])) {
                App::abort(404);
            }

            $id = (int) $params[3];

            $instance = new $modelString;
            $instance = $instance->findOrFail($id);

            return $instance;
        });
    }

    protected function registerCommands()
    {
        $this->app['command.manager.medias.configure'] = $this->app->share(function($app)
        {
            return new ConfigureCommand;
        });

        $this->commands('command.manager.medias.configure');
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return array('command.manager.medias.configure');
    }

}
