<?php namespace EscapeWork\Manager\Medias\Repositories\Media;

use EscapeWork\Manager\Repositories\BaseEloquentRepository;
use EscapeWork\Manager\Medias\Models\Media;
use EscapeWork\Manager\Medias\Models\MediaModelSize;
use EscapeWork\Manager\Medias\Upload;

class EloquentMediaRepository extends BaseEloquentRepository implements MediaRepository
{

    /**
     * MediaModelSize
     *
     * @var  EscapeWork\Manager\Medias\Models\MediaModelSize
     */
    protected $mediaModelSize;

    public function __construct(Media $model, MediaModelSize $mediaModelSize)
    {
        $this->model          = $model;
        $this->mediaModelSize = $mediaModelSize;
    }

    public function setMediaModel($model)
    {
        $this->model->media_model = $model;
    }

    public function insert($picture, $attrs = array())
    {
        $upload = Upload::create(
            $this->model->dir(),
            $picture,
            $this->getMediaModelSizes()
        );

        if (! $upload instanceof Upload) {
            return;
        }

        $media              = new Media($attrs);
        $media->media_model = $this->media_model;
        $media->model_id    = $this->model_id;
        $media->file        = $upload->getName();
        $media->mime        = $upload->getMime();
        $media->size        = $upload->getSize();
        $media->order       = $this->getLastOrder();
        return $media->save();
    }

    /**
     * Buscando os tamanhos na classe MediaModelSize e formatando para a classe EscapeWork\Resize
     *
     * @param  string $model
     * @return array
     */
    public function getMediaModelSizes()
    {
        $sizes = $this->mediaModelSize->getSizes($this->model->media_model);

        $arrSizes = array(
            'manager-' => array(
                'width'  => 270,
                'height' => 300,
                'crop'   => false,
            )
        );

        foreach ($sizes as $size) {
            $size['crop'] = $size['resize'] ? false : true;

            $arrSizes[$size['prefix']] = $size;
        }

        return $arrSizes;
    }

    protected function getLastOrder()
    {
        $media = $this->model
                      ->getActualModel()
                      ->orderBy('order', 'DESC')
                      ->first();

        if ($media) {
            return $media->order + 1;
        }

        return 1;
    }

    public function getMedias()
    {
        return $this->model
                    ->getActualModel()
                    ->orderBy('order')
                    ->orderBy('created_at', 'DESC')
                    ->get();
    }

    public function getMedia()
    {
        return $this->getActualModel()
                ->orderBy('order')
                ->orderBy('created_at', 'DESC')
                ->take(1)
                ->first();
    }

    public function delete()
    {
        $this->deleteFiles();

        return $this->model->delete();
    }

    public function deleteAll()
    {
        $medias = $this->getMedias();

        foreach ($medias as $media) {
            $media->delete();
        }
    }

    public function deleteFiles()
    {
        $sizes = $this->getMediaModelSizes();

        foreach ($sizes as $prefix => $size) {
            $file = $this->model->dir() . $prefix . $this->file;

            if (is_file($file)) {
                unlink($file);
            }
        }

        $file = $this->model->dir() . $this->file;

        if (is_file($file)) {
            unlink($file);
        }
    }
}
